@@ -27,9 +27,9 @@ a listening socket under various protocols.
 from __future__ import absolute_import
 
 import time
+from socket import getfqdn
 
 import gevent
-from gevent.socket import getfqdn
 from gevent.server import StreamServer
 from gevent.ssl import SSLSocket
 
@@ -45,8 +45,9 @@ class Edge(object):
     directly inherit :class:`EdgeServer` and thus indirectly inherit
     :class:`Edge`.
 
-    :param queue: |Queue| (Or |Queue|-like) object that will take responsibility
-                  for delivery of messages received by the :class:`Edge`.
+    :param queue: |Queue| (Or |Queue|-like) object that will take
+                  responsibility for delivery of messages received by the
+                  :class:`Edge`.
     :param hostname: String identifying the local machine, stamped to each
                      received message in its
                      :attr:`~slimta.envelope.Envelope.receiver` attribute for
@@ -77,20 +78,38 @@ class Edge(object):
         envelope.receiver = self.hostname
         envelope.timestamp = time.time()
 
-        return self.queue.enqueue(envelope)
+        try:
+            return self.queue.enqueue(envelope)
+        except Exception:
+            logging.log_exception(__name__)
+            raise
+
+    def kill(self):
+        """.. versionadded:: 0.3.15
+
+        This method is used by |Edge| and |Edge|-like objects to properly end
+        associated services (such as running :class:`~gevent.Greenlet` threads)
+        and close resources.
+
+        """
+        pass
 
 
 class EdgeServer(Edge, gevent.Greenlet):
     """This class implements a :class:`~gevent.Greenlet` serving a
     :class:`~gevent.server.StreamServer` until killed. Connections are accepted
     on the socket and passed to :meth:`.handle()`, which should be overriden
-    by implementers of this base class. The socket will be closed automatically.
+    by implementers of this base class. The socket will be closed
+    automatically.
 
     :param queue: |Queue| object used by :meth:`.handoff()` to ensure the
                   envelope is properly queued before acknowledged by the edge
                   service.
     :param listener: Usually a ``(ip, port)`` tuple defining the interface and
-                     port upon which to listen for connections.
+                     port upon which to listen for connections. See
+                     the ``listener`` parameter to
+                     :class:`~gevent.baseserver.BaseServer` for more
+                     information.
     :param pool: If given, defines a specific :class:`gevent.pool.Pool` to
                  use for new greenlets.
     :param hostname: String identifying the local machine. See |Edge| for more
@@ -105,7 +124,11 @@ class EdgeServer(Edge, gevent.Greenlet):
 
     def _handle(self, socket, address):
         log.accept(self.server.socket, socket, address)
-        self.handle(socket, address)
+        try:
+            self.handle(socket, address)
+        except Exception:
+            logging.log_exception(__name__)
+            raise
 
     def handle(self, socket, address):
         """Override this function to receive messages on the socket and call
@@ -114,11 +137,14 @@ class EdgeServer(Edge, gevent.Greenlet):
         :param socket: The socket for the connected client.
         :param address: The address of the connected client.
 
-        :raises: :class:`NotImplementedError`
+        :raises: :py:exc:`NotImplementedError`
 
         """
         raise NotImplementedError()
 
+    def kill(self):
+        self.server.stop()
+
     def _run(self):
         self.server.start()
         self.server.serve_forever()
