@@ -1,5 +1,5 @@
 
-import unittest
+from assertions import *
 
 from mox import MoxTestBase, IsA
 
@@ -12,14 +12,14 @@ class TestStaticSmtpRelay(MoxTestBase):
     def test_add_client(self):
         static = StaticSmtpRelay('testhost')
         ret = static.add_client()
-        self.assertIsInstance(ret, SmtpRelayClient)
+        assert_is_instance(ret, SmtpRelayClient)
 
     def test_add_client_custom(self):
         def fake_class(addr, queue, **kwargs):
-            self.assertEqual(('testhost', 25), addr)
+            assert_equal(('testhost', 25), addr)
             return 'success'
         static = StaticSmtpRelay('testhost', client_class=fake_class)
-        self.assertEqual('success', static.add_client())
+        assert_equal('success', static.add_client())
 
 
 # vim:et:fdm=marker:sts=4:sw=4:ts=4
